#!/usr/bin/perl -w
# Chequeo pasivo de host
#
#
# 1.2: 2024-02-08 daniel
#      Corrijo parseo de opciones
#      Creo nuevo check_nrdp_host.pl basado en el check_nsca_host.pl
#
# 1.1: 2014-05-14 daniel
#      Cambios en comentarios, uso &print_version para version
#      Agrego opcion -P para el puerto del NSCA
#
# 1.0: 2014-05-05 daniel
#      Version inicial

use strict;
use Net::SNMP qw(:snmp);
use Data::Dumper;
use Getopt::Long;
use lib "/usr/lib64/nagios/plugins";
use utils qw($TIMEOUT %ERRORS);
use ipsupervisor qw(&send_nsca &round &check_drbd &read_config &print_version 
                    $nagios_hostname $nagios_hostname_ha $nsca_host $nsca_port $debug $snmp_timeout $nrdp_url $nrdp_token);

my ($opt_h, $opt_V, $opt_v, $opt_N, $opt_H, $opt_U, $opt_d);
my $PROGNAME = $0;

sub print_usage();

&read_config();
$opt_H = $nagios_hostname if $nagios_hostname;
$opt_N = $nrdp_url if $nrdp_url;

Getopt::Long::Configure('bundling');
GetOptions
    ("h"   => \$opt_h, "help"           => \$opt_h,
     "V"   => \$opt_V, "version"        => \$opt_V,

     "N=s" => \$opt_N, "nrdp=s"         => \$opt_N,
     "H=s" => \$opt_H, "hostname=s"     => \$opt_H,
     "U"   => \$opt_U, "unreachable"    => \$opt_U,
     "d"   => \$opt_d, "debug"          => \$opt_d);

if ($opt_V) {
    print_version($PROGNAME,'1.2');
    exit $ERRORS{'OK'};
}

if ($opt_h) {
	print_usage();
	exit $ERRORS{'OK'};
}

# Hostname Centreon (requerido)
(print("Nagios hostname required!\n") && print_usage() && exit $ERRORS{'UNKNOWN'}) unless ($opt_H);

# NRDP Url (requerido)
(print("NRDP Url required!\n") && print_usage() && exit $ERRORS{'UNKNOWN'}) unless ($opt_N);

# Debug
$debug = $opt_d;

my ($res, $status);
unless ($opt_U) {
    $res = "Host Alive";
    $status = 0;
} else {
    $res = "Host unreachable (forced)";
    $status = 2;
}

my $nrdp_str = "$opt_H|$status|$res\n";
print "send_nrdp: $nrdp_str" if $debug;
system("/usr/bin/send_nrdp.sh -u $opt_N -t $nrdp_token -H $opt_H -S $status -o \"$res\"");
print "\n" if $debug;

if ($nagios_hostname_ha) {
    #undef $nsca_str;
    my $drbd = &check_drbd();
    unless ($opt_U) {
	if ($drbd == 1) {
	    # Host UP
            $res = "HA Host Alive";
	    $status = 0;
	} elsif ($drbd == -1) {
	    # Host DOWN
	    $res = "HA Host Down";
	    $status = 1;
	}
    } else {
	$res = "HA Host unreachable (forced)";
	$status = 2;
    }

    $nrdp_str = "$opt_H|$status|$res\n";
    print "send_nrdp: $nrdp_str" if $debug;
    system("/usr/bin/send_nrdp.sh -u $opt_N -t $nrdp_token -H $opt_H -S $status -o \"$res\"");
    print "\n" if $debug;
} 


sub print_usage () {
    print "\nUsage:\n";
    print "$PROGNAME\n";
    print "   -N (--nsca)         NSCA host to send passive check (required)\n";
    print "   -H (--hostname)     Nagios hostname (required)\n";
    print "   -P (--port)         NSCA port to send passive check (default 5667)\n";
    print "   -U (--unreachable)  Force status UNREACHABLE for host\n";
    print "   -d (--debug)        Enable NSCA debug (default disabled)\n";
    print "   -V (--version)      Plugin version\n";
    print "   -h (--help)         usage help\n";
}
