# IPSupervisor common subroutines package
#
#
# 1.4: 2024-02-08 daniel
#      Se agregan variables para usar NRDP

# 1.3: 2022-04-05 daniel
#      Compatible con drbd9
#
# 1.1: 2014-05-14 daniel
#      Uso &print_version para version
#      Soporto cambiar el puerto del NSCA, parametro 'nsca_port' en /etc/nagios/ipsupervisor.conf
#
# 1.0: 2014-05-05 daniel
#      Version inicial

package ipsupervisor;
use Exporter;
@ISA = qw(Exporter);
@EXPORT = qw(&send_nsca &round &check_drbd &read_config &print_version
             $nagios_hostname $nagios_hostname_ha $nsca_host $nsca_port $debug $snmp_timeout $nrdp_url $nrdp_token);

$debug = 0;
$snmp_timeout = 5;
$nsca_host = "";
$nsca_port = 5667;
$nagios_hostname = "";
$nagios_hostname_ha = "";
$nrdp_url = "";
$nrdp_token = "xK5bnjDUPYQh2a8zTdAF6W";
1;

sub send_nsca {
    my ($line,$host) = @_;
    open(NSCA, "|/usr/sbin/send_nsca -H $host -d \\| -c /etc/nagios/send_nsca.cfg -p $nsca_port") || die "Error al abrir pipe!\n"; 
    print NSCA $line;
    print "send_nsca: $line\n" if $debug;
    close NSCA;
}

sub round {
    my $float = shift;
    return ($float == 0) ? 0 : int($float + $float/abs($float*2));
}

# Check for DRBD active
# Returns:
# -1 if no DRBD config
#  1 if DRBD, and host is primary
#  0 if DRBD, and host is not primary
sub check_drbd {
    my $res = -1;
    if (-r '/proc/drbd' ) {
	my $drbd = `/usr/sbin/drbdadm role ipcontact 2> /dev/null`;
	my $ro = 0;
	$ro = $1 if $drbd =~ /^(\w+)/;
	# Returns 1 if primary, 0 otherwise
	$res = ($ro eq 'Primary');
    }
    return $res;
}


sub read_config {
    open(CONFIG, "/etc/nagios/ipsupervisor.conf") || warn "/etc/nagios/ipsupervisor.conf doesn't exists!\n";
    while ($line = <CONFIG>) {
	next if ($line =~ /^\s*\#\w*/);
	$nagios_hostname = $1 if ($line =~ /^\s*nagios_hostname\s*=\s*(\w+)/);
	$nagios_hostname_ha = $1 if ($line =~ /^\s*nagios_hostname_ha\s*=\s*(\w+)/);
	$nsca_host = $1 if ($line =~ /^\s*nsca_host\s*=\s*([\w.]+)/);
	$nsca_port = $1 if ($line =~ /^\s*nsca_port\s*=\s*(\d+)/);
	$nrdp_url = $1 if ($line =~ /^\s*nrdp_url\s*=\s*([\w.\/:]+)/);
    }
    #print "Read from config: nsca_host: $nsca_host, nagios_hostname: $nagios_hostname\n";
    close CONFIG;
}

sub print_version ($$) {
	my $commandName = shift;
	my $pluginRevision = shift;
	print "$commandName v$pluginRevision (ipsupervisor-plugins 1.4)\n";
}
